/*
 * Copyright (C) 2003 Helge Deller <deller@kde.org>
 */

#ifndef _KMOBILEPREF_H_
#define _KMOBILEPREF_H_

#include <kdialogbase.h>
#include <tqframe.h>

class KMobilePrefPageOne;
class KMobilePrefPageTwo;

class KMobilePreferences : public KDialogBase
{
    Q_OBJECT
  TQ_OBJECT
public:
    KMobilePreferences();

private:
    KMobilePrefPageOne *m_pageOne;
    KMobilePrefPageTwo *m_pageTwo;
};

class KMobilePrefPageOne : public TQFrame
{
    Q_OBJECT
  TQ_OBJECT
public:
    KMobilePrefPageOne(TQWidget *parent = 0);
};

class KMobilePrefPageTwo : public TQFrame
{
    Q_OBJECT
  TQ_OBJECT
public:
    KMobilePrefPageTwo(TQWidget *parent = 0);
};

#endif // _KMOBILEPREF_H_
